@@ -103,7 +103,7 @@ Bibliography::Bibliography(KaspaURL url, Sql *conn, QWidget* parent,	const char*
 }
 
 Bibliography::~Bibliography() {
-  debug("Bibliography::~Bibliography");
+//  debug("Bibliography::~Bibliography");
   delete publ;
 }
 
@@ -118,7 +118,7 @@ bool Bibliography::isValid() {
 
 void Bibliography::reread() {
 	try {
-	  debug("Bibliography::reread()");
+//	  debug("Bibliography::reread()");
   	setWorkingGUI();
 	  publ->reset();
 	} catch(KaspaErr& err) {
@@ -131,6 +131,7 @@ void Bibliography::setFields() {
   if(isValid()) {
 		try {
 			setWorkingGUI();
+      emit setCaption(publ->getTitle());
   		pages->setText(publ->getPages());
 	  	title->setText(publ->getTitle());
 	  	translator->setText(publ->getTranslator());
@@ -229,7 +230,7 @@ void Bibliography::flush() {
 }
 
 void Bibliography::save(bool block) {
-  debug("Bibliography::save()");
+//  debug("Bibliography::save()");
 	try {
 	  if(isValid() && !isReadOnly() && !isWorking()) {
     	if(strcmp(pages->text(), publ->getPages()))
@@ -262,7 +263,7 @@ void Bibliography::save(bool block) {
 }
 
 void Bibliography::setInvalidGUI() {
-  debug("Bibliography::setInvalidGUI()");
+//  debug("Bibliography::setInvalidGUI()");
   Inherited::setInvalidGUI();
   lockGUI();
 	for(unsigned int i=0; i<sizeof(bibliocs)/sizeof(CommandSetup); i++)
@@ -271,7 +272,7 @@ void Bibliography::setInvalidGUI() {
 }	
 
 void Bibliography::setReadWriteGUI() {
-  debug("Bibliography::setReadWriteGUI()");
+//  debug("Bibliography::setReadWriteGUI()");
   Inherited::setReadWriteGUI();
   unlockGUI();
 	for(unsigned int i=0; i<sizeof(bibliocs)/sizeof(CommandSetup); i++)
@@ -280,7 +281,7 @@ void Bibliography::setReadWriteGUI() {
 }
 
 void Bibliography::setReadOnlyGUI() {
-  debug("Bibliography::setReadOnlyGUI()");	
+//  debug("Bibliography::setReadOnlyGUI()");	
   Inherited::setReadOnlyGUI();
   lockGUI();
 	for(unsigned int i=0; i<sizeof(bibliocs)/sizeof(CommandSetup); i++)
@@ -289,7 +290,7 @@ void Bibliography::setReadOnlyGUI() {
 }
 
 void Bibliography::setWorkingGUI() {
-  debug("Bibliography::setWorkingGUI()");
+//  debug("Bibliography::setWorkingGUI()");
 	if(isReadOnly() || !isValid()) {
 		lockGUI();
 	  if(btfields) btfields->setWorkingGUI(true);
@@ -326,24 +327,24 @@ bool Bibliography::closeRequest() {
 KToolBar *Bibliography::getToolBar() {
 	KaspaToolBar *toolbar = new KaspaToolBar(topLevelWidget());
 
-  toolbar->insertButton(BarIcon("showpubl.xpm"), ID_BIBLIO_SHOWPUBL, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showpubl.png"), ID_BIBLIO_SHOWPUBL, SIGNAL(clicked()),
 				this, SLOT(showPubl()), true, i18n("Show Publication") );
-  toolbar->insertButton(BarIcon("showpublisher.xpm"), ID_BIBLIO_SHOWORGPUBLISHER, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showpublisher.png"), ID_BIBLIO_SHOWORGPUBLISHER, SIGNAL(clicked()),
 				this, SLOT(showOrgPublisher()), true, i18n("Show Publisher") );
 
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("inspublisher.xpm"), ID_BIBLIO_INSORGPUBLISHER, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("inspublisher.png"), ID_BIBLIO_INSORGPUBLISHER, SIGNAL(clicked()),
 				this, SLOT(insertOrgPublisher()), true, i18n("Insert Publisher") );
-  toolbar->insertButton(BarIcon("newpublisher.xpm"), ID_BIBLIO_NEWORGPUBLISHER, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("newpublisher.png"), ID_BIBLIO_NEWORGPUBLISHER, SIGNAL(clicked()),
 				this, SLOT(newOrgPublisher()), true, i18n("New Publisher") );
 
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("filedel.xpm"), ID_BIBLIO_DELREC, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("filedel.png"), ID_BIBLIO_DELREC, SIGNAL(clicked()),
 				this, SLOT(del()), true, i18n("Delete Record") );
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("filefloppy.xpm"), ID_BIBLIO_FLUSH, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("filefloppy.png"), ID_BIBLIO_FLUSH, SIGNAL(clicked()),
 				this, SLOT(flush()), true, i18n("Save Changes") );
-  toolbar->insertButton(BarIcon("reload.xpm"), ID_BIBLIO_RESET, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("reload.png"), ID_BIBLIO_RESET, SIGNAL(clicked()),
 				this, SLOT(reread()), true, i18n("Revert Record") );
 
 
