@@ -17,6 +17,7 @@
 
 
 #include "bibtexfactory.h"
+#include <qregexp.h>
 
 BibTexFactory::BibTexFactory(){
 }
@@ -25,64 +26,64 @@ BibTexFactory::~BibTexFactory(){
 
 QString BibTexFactory::ascii2latex(QString &t) {
   QString s(t);
-  s.replace(QString().fromLatin1(""),"\"A");
-  s.replace(QString().fromLatin1(""),"\"E");
-  s.replace(QString().fromLatin1(""),"\"I");
-  s.replace(QString().fromLatin1(""),"\"O");
-  s.replace(QString().fromLatin1(""),"\"U");
-  s.replace(QString().fromLatin1(""),"\"a");
-  s.replace(QString().fromLatin1(""),"\"e");
-  s.replace(QString().fromLatin1(""),"\"i");
-  s.replace(QString().fromLatin1(""),"\"o");
-  s.replace(QString().fromLatin1(""),"\"u");
-  s.replace(QString().fromLatin1(""),"\\\"{y}");
-  s.replace(QString().fromLatin1(""),"{}\\AE}");
-  s.replace(QString().fromLatin1(""),"{}\\ae}");
-  s.replace(QString().fromLatin1(""),"\"s");
-  s.replace(QString().fromLatin1(""),"\\'{A}");
-  s.replace(QString().fromLatin1(""),"\\'{E}");
-  s.replace(QString().fromLatin1(""),"\\'{I}");
-  s.replace(QString().fromLatin1(""),"\\'{O}");
-  s.replace(QString().fromLatin1(""),"\\'{U}");
-  s.replace(QString().fromLatin1(""),"\\'{Y}");
-  s.replace(QString().fromLatin1(""),"\\'{a}");
-  s.replace(QString().fromLatin1(""),"\\'{e}");
-  s.replace(QString().fromLatin1(""),"\\'{i}");
-  s.replace(QString().fromLatin1(""),"\\'{o}");
-  s.replace(QString().fromLatin1(""),"\\'{u}");
-  s.replace(QString().fromLatin1(""),"\\'{y}");
-  s.replace(QString().fromLatin1(""),"\\`{A}");
-  s.replace(QString().fromLatin1(""),"\\`{E}");
-  s.replace(QString().fromLatin1(""),"\\`{I}");
-  s.replace(QString().fromLatin1(""),"\\`{O}");
-  s.replace(QString().fromLatin1(""),"\\`{U}");
-  s.replace(QString().fromLatin1(""),"\\`{a}");
-  s.replace(QString().fromLatin1(""),"\\`{e}");
-  s.replace(QString().fromLatin1(""),"\\`{i}");
-  s.replace(QString().fromLatin1(""),"\\`{o}");
-  s.replace(QString().fromLatin1(""),"\\`{u}");
-  s.replace(QString().fromLatin1(""),"\\^{A}");
-  s.replace(QString().fromLatin1(""),"\\^{E}");
-  s.replace(QString().fromLatin1(""),"\\^{I}");
-  s.replace(QString().fromLatin1(""),"\\^{O}");
-  s.replace(QString().fromLatin1(""),"\\^{U}");
-  s.replace(QString().fromLatin1(""),"\\^{a}");
-  s.replace(QString().fromLatin1(""),"\\^{e}");
-  s.replace(QString().fromLatin1(""),"\\^{i}");
-  s.replace(QString().fromLatin1(""),"\\^{o}");
-  s.replace(QString().fromLatin1(""),"\\^{u}");
-  s.replace(QString().fromLatin1(""),"\\~{A}");
-  s.replace(QString().fromLatin1(""),"\\~{N}");
-  s.replace(QString().fromLatin1(""),"\\~{O}");
-  s.replace(QString().fromLatin1(""),"\\~{a}");
-  s.replace(QString().fromLatin1(""),"\\~{n}");
-  s.replace(QString().fromLatin1(""),"\\~{o}");
-  s.replace(QString().fromLatin1(""),"\\r{A}");
-  s.replace(QString().fromLatin1(""),"\\r{a}");
-  s.replace(QString().fromLatin1(""),"\\c{C}");
-  s.replace(QString().fromLatin1(""),"\\c{c}");
-  s.replace(QString().fromLatin1(""),"\\O");
-  s.replace(QString().fromLatin1(""),"\\o");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"A");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"E");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"I");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"O");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"U");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"a");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"e");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"i");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"o");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"u");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\\"{y}");
+  s.replace(QRegExp(QString().fromLatin1("")),"{}\\AE}");
+  s.replace(QRegExp(QString().fromLatin1("")),"{}\\ae}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\"s");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{A}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{E}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{I}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{O}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{U}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{Y}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{a}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{e}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{i}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{o}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{u}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\'{y}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{A}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{E}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{I}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{O}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{U}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{a}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{e}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{i}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{o}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\`{u}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{A}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{E}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{I}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{O}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{U}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{a}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{e}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{i}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{o}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\^{u}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\~{A}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\~{N}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\~{O}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\~{a}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\~{n}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\~{o}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\r{A}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\r{a}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\c{C}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\c{c}");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\O");
+  s.replace(QRegExp(QString().fromLatin1("")),"\\o");
   return s;
 }
 
