@@ -18,7 +18,7 @@
 MimeTypes::MimeTypes(QWidget* parent,	const char* name)
 	:	Inherited( parent, name )
 {
-  debug("Mimetypes::Mimetypes()");
+//  debug("Mimetypes::Mimetypes()");
   KMimeType::List l=KMimeType::allMimeTypes();
 
   KMimeType::List::Iterator it1;
@@ -26,15 +26,20 @@ MimeTypes::MimeTypes(QWidget* parent,	const char* name)
     list.append(new QString((*it1)->name()));
   list.sort();
 
+  KGlobal::config()->setGroup("Convert2Text");
+
   QListIterator<QString> it2(list);
   for(; it2.current(); ++it2 )
     mimetypelist->insertItem( *(*it2)+" : "+KGlobal::config()->readEntry( *(*it2), "-"));
+
+  KGlobal::config()->setGroup("");
 }
 
 
 void MimeTypes::slotSelected(int i)
 {
   bool b;
+  KGlobal::config()->setGroup("Convert2Text");
   QString s=KLineEditDlg::getText("Command (type '-' to clear commandline): ", KGlobal::config()->readEntry( *list.at(i), ""), &b, this);
   if(b) {
     if(s=="-") {
@@ -46,6 +51,7 @@ void MimeTypes::slotSelected(int i)
       mimetypelist->changeItem(*list.at(i)+" : "+s, i);
     }
   }
+  KGlobal::config()->setGroup("");
 }
 
 
