@@ -49,7 +49,7 @@
 #include "kaspasql.h"
 #include <kscan.h>
 #include <qbuffer.h>
-#include <iostream.h>
+// #include <iostream.h>
 #include "processfiledlg.h"
 #define  Inherited PartData
 
@@ -78,7 +78,7 @@ Part::Part(KaspaURL url, Sql *conn, QWidget* parent,	const char* name):
 	setTabOrder(key, pages);
 	setTabOrder(pages, bibtex);
 
-	debug("Part::Part(QString, QWidget, char*)");
+//	debug("Part::Part(QString, QWidget, char*)");
   part = new PartBase(url.where(), conn);
   ASSERT(part);
 	part->setCallBack(&idle);
@@ -107,7 +107,7 @@ Part::Part(KaspaURL url, Sql *conn, QWidget* parent,	const char* name):
 
 Part::~Part()
 {
-	debug("Part::~Part()");
+//	debug("Part::~Part()");
 	delete part;
 	delete pt;
 }
@@ -139,6 +139,7 @@ void Part::reread() {
 void Part::setFields() {
   if(isValid()) {
 		setWorkingGUI();
+    emit setCaption(part->getTitle());
 	  title->setText(part->getTitle());
 		havefirstfile=!(part->getFirstFile()==InvalidOid);
 
@@ -412,27 +413,27 @@ void Part::showIntro() {
 
 KToolBar *Part::getToolBar() {
 	KaspaToolBar *toolbar = new KaspaToolBar(topLevelWidget());
-  toolbar->insertButton(BarIcon("showmemo.xpm"), ID_PART_SHOWMEMO, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showmemo.png"), ID_PART_SHOWMEMO, SIGNAL(clicked()),
 				this, SLOT(showPartMemo()), true, i18n("Show Memo") );
-  toolbar->insertButton(BarIcon("showpubl.xpm"), ID_PART_SHOWPUBL, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showpubl.png"), ID_PART_SHOWPUBL, SIGNAL(clicked()),
 				this, SLOT(showPubl()), true, i18n("Show Publication") );
-  toolbar->insertButton(BarIcon("showintro.xpm"), ID_PART_SHOWINTRO, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("showintro.png"), ID_PART_SHOWINTRO, SIGNAL(clicked()),
 				this, SLOT(showIntro()), true, i18n("Show Intro") );
 
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("newnote.xpm"), ID_PART_NEWLINK, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("newnote.png"), ID_PART_NEWLINK, SIGNAL(clicked()),
 				this, SLOT(newLink()), true, i18n("New Note") );
-  toolbar->insertButton(BarIcon("insnote.xpm"), ID_PART_INSLINK, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("insnote.png"), ID_PART_INSLINK, SIGNAL(clicked()),
 				this, SLOT(insLink()), true, i18n("Insert Note") );
-  toolbar->insertButton(BarIcon("delnote.xpm"), ID_PART_REMLINK, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("delnote.png"), ID_PART_REMLINK, SIGNAL(clicked()),
 				this, SLOT(remLink()), true, i18n("Delete Note") );
 
 	toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("newauthor.xpm"), ID_PART_NEWAUTHOR, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("newauthor.png"), ID_PART_NEWAUTHOR, SIGNAL(clicked()),
 				this, SLOT(newAuthor()), true, i18n("New Author") );
-  toolbar->insertButton(BarIcon("insauthor.xpm"), ID_PART_INSAUTHOR, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("insauthor.png"), ID_PART_INSAUTHOR, SIGNAL(clicked()),
 				this, SLOT(insAuthor()), true, i18n("Insert Author") );
-  toolbar->insertButton(BarIcon("delauthor.xpm"), ID_PART_REMAUTHOR, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("delauthor.png"), ID_PART_REMAUTHOR, SIGNAL(clicked()),
 				this, SLOT(remAuthor()), true, i18n("Remove Author") );
 
   toolbar->insertLineSeparator();
@@ -441,13 +442,13 @@ KToolBar *Part::getToolBar() {
   toolbar->insertButton(BarIcon("text.png"), ID_PART_OCR, SIGNAL(clicked()),
 				this, SLOT(slotOcrText()), true, i18n("OCR") );
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("filedel.xpm"), ID_PART_DELREC, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("filedel.png"), ID_PART_DELREC, SIGNAL(clicked()),
 				this, SLOT(del()), true, i18n("Delete Record") );
 
   toolbar->insertLineSeparator();
-  toolbar->insertButton(BarIcon("filefloppy.xpm"), ID_PART_FLUSH, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("filefloppy.png"), ID_PART_FLUSH, SIGNAL(clicked()),
 				this, SLOT(flush()), true, i18n("Save Changes") );
-  toolbar->insertButton(BarIcon("reload.xpm"), ID_PART_RESET, SIGNAL(clicked()),
+  toolbar->insertButton(BarIcon("reload.png"), ID_PART_RESET, SIGNAL(clicked()),
 				this, SLOT(reread()), true, i18n("Revert Record") );
 	toolbar->setBarPos(KToolBar::Top);
 	toolbar->enable(KToolBar::Show);
@@ -615,7 +616,7 @@ void Part::slotExportFiles() {
     	// Build path+filename
     	QString n(dir);
       n+=filename.right(filename.length()-filename.findRev("/")-1);
-    	debug("FileIODlg::exportItem() - file: %s", (const char *) n);
+//    	debug("FileIODlg::exportItem() - file: %s", (const char *) n);
 
     	// Open file...
     	QFile f(n);
@@ -658,7 +659,7 @@ void Part::slotDeleteFiles() {
 		if(! (count && (KMessageBox::questionYesNo(this, i18n("Delete Files?"), "Delete Rec") == KMessageBox::Yes)))
       return;
 
-		QProgressDialog pd(i18n("Deleting Files"), i18n("Abort"), count, this);
+		QProgressDialog pd(i18n("Deleting Files"), i18n("Abort"), count, this, "delprogress", true);
     flush();
 
 		// delete files...	
@@ -678,7 +679,7 @@ void Part::slotDeleteFiles() {
 
 void Part::slotScanImage() {
 
-  scanDialog = KScanDialog::getScanDialog( this, "scandialog" );
+  scanDialog = KScanDialog::getScanDialog( this, "scandialog", true );
   if ( !scanDialog ) {
 		KMessageBox::error(this, "No support for scanning found!");
     return;
@@ -705,7 +706,7 @@ void Part::slotScanned(const QImage& img, int id) {
   iio.setFormat("PNG");
   iio.write();
   b.close();
-  cout<<"Part::slotScanned(): bufsize="<<ba.size();
+//  cout<<"Part::slotScanned(): bufsize="<<ba.size();
 
   // New PartData-record...
   PartDataBase file(part->id(), sql);
@@ -713,7 +714,7 @@ void Part::slotScanned(const QImage& img, int id) {
   file.setData(KCodecs::base64Encode(ba, false));
   file.setType("image/png");
   file.flush();
-  scanDialog->close();
+//  scanDialog->close();
   save();
   setFields();
 }
@@ -743,7 +744,7 @@ void Part::slotOcrText() {
 
 void Part::slotOcred(const QString& s, int id) {
 
-  cout<<"Part::slotOcred(): s="<<s;
+//  cout<<"Part::slotOcred(): s="<<s;
 
   // New PartData-record...
   PartDataBase file(part->id(), sql);
@@ -788,4 +789,6 @@ void Part::moveAuthorDown(Oid i) {
   part->moveAuthorDown(i);
 	save();
 	setFields();	
-}
\ No newline at end of file
+}
+
+
